@@ -1,5 +1,5 @@
 ## File Name: frm_prepare_models.R
-## File Version: 0.504
+## File Version: 0.509
 
 frm_prepare_models <- function(dep, ind, dat0, nodes_control, nodes_weights=TRUE, use_grad=2,
     use_gibbs=FALSE, weights=NULL )
@@ -14,6 +14,9 @@ frm_prepare_models <- function(dep, ind, dat0, nodes_control, nodes_weights=TRUE
         res <- frm_formula_extract_terms( ind[[mm]]$formula )
         all_vars <- c( all_vars, res$all_vars )
         dv_vars <- c( dv_vars, res$dv_vars )
+        names_ind <- names(ind)
+        names_ind[mm] <- paste(res$dv_form)
+        names(ind) <- names_ind
         res <- frm_append_list( list1=ind[[mm]], list2=res )
         ## depends on regression model classes
         res1 <- frm_define_model_R_function(model=res, use_grad=use_grad,
